Method: PDNS::Config#change

Defined in:
lib/pdns_api/config.rb

#change(value = nil) ⇒ Object

Updates the object on the server.

If value is set, the current value is used. If value is not set, value is updated and then used.



78
79
80
81
# File 'lib/pdns_api/config.rb', line 78

def change(value = nil)
  value(value)
  @http.put(@url, @info)
end